==> frostiful-2.2.6%2B1.21.1-sources.jar: com/github/thedeathlycow/frostiful/client/anim/BiterAnimations.java <==
package com.github.thedeathlycow.frostiful.client.anim;

import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_7179;
import net.minecraft.class_7184;
import net.minecraft.class_7186;
import net.minecraft.class_7187;

@Environment(EnvType.CLIENT)
public class BiterAnimations {
    public static final class_7184 BITE = class_7184.class_7185.method_41818(0.225f)
            .method_41820("head",
                    new class_7179(class_7179.class_7183.field_37886,
                            new class_7186(0f, class_7187.method_41823(0f, 0f, 0f),
                                    class_7179.class_7181.field_37884),
                            new class_7186(0.1125f, class_7187.method_41823(0f, 2f, -4f),
                                    class_7179.class_7181.field_37884),
                            new class_7186(0.225f, class_7187.method_41823(0f, 0f, 0f),
                                    class_7179.class_7181.field_37884)))
            .method_41820("bottom",
                    new class_7179(class_7179.class_7183.field_37887,
                            new class_7186(0f, class_7187.method_41829(0f, 0f, 0f),
                                    class_7179.class_7181.field_37884),
                            new class_7186(0.1125f, class_7187.method_41829(27.5f, 0f, 0f),
                                    class_7179.class_7181.field_37884),
                            new class_7186(0.225f, class_7187.method_41829(0f, 0f, 0f),
                                    class_7179.class_7181.field_37884)))
            .method_41820("top",
                    new class_7179(class_7179.class_7183.field_37887,
                            new class_7186(0f, class_7187.method_41829(0f, 0f, 0f),
                                    class_7179.class_7181.field_37884),
                            new class_7186(0.1125f, class_7187.method_41829(-75f, 0f, 0f),
                                    class_7179.class_7181.field_37884),
                            new class_7186(0.225f, class_7187.method_41829(0f, 0f, 0f),
                                    class_7179.class_7181.field_37884))).method_41821();
}

==> frostiful-2.2.8%2B1.21.8-sources.jar: com/github/thedeathlycow/frostiful/client/anim/BiterAnimations.java <==
package com.github.thedeathlycow.frostiful.client.anim;

import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_7179;
import net.minecraft.class_7184;
import net.minecraft.class_7186;
import net.minecraft.class_7187;
import net.minecraft.client.render.entity.animation.*;

@Environment(EnvType.CLIENT)
public class BiterAnimations {
    public static final class_7184 BITE = class_7184.class_7185.method_41818(0.225f)
            .method_41820("head",
                    new class_7179(class_7179.class_7183.field_37886,
                            new class_7186(0f, class_7187.method_41823(0f, 0f, 0f),
                                    class_7179.class_7181.field_37884),
                            new class_7186(0.1125f, class_7187.method_41823(0f, 2f, -4f),
                                    class_7179.class_7181.field_37884),
                            new class_7186(0.225f, class_7187.method_41823(0f, 0f, 0f),
                                    class_7179.class_7181.field_37884)))
            .method_41820("mouth_bottom",
                    new class_7179(class_7179.class_7183.field_37887,
                            new class_7186(0f, class_7187.method_41829(0f, 0f, 0f),
                                    class_7179.class_7181.field_37884),
                            new class_7186(0.1125f, class_7187.method_41829(27.5f, 0f, 0f),
                                    class_7179.class_7181.field_37884),
                            new class_7186(0.225f, class_7187.method_41829(0f, 0f, 0f),
                                    class_7179.class_7181.field_37884)))
            .method_41820("mouth_top",
                    new class_7179(class_7179.class_7183.field_37887,
                            new class_7186(0f, class_7187.method_41829(0f, 0f, 0f),
                                    class_7179.class_7181.field_37884),
                            new class_7186(0.1125f, class_7187.method_41829(-75f, 0f, 0f),
                                    class_7179.class_7181.field_37884),
                            new class_7186(0.225f, class_7187.method_41829(0f, 0f, 0f),
                                    class_7179.class_7181.field_37884))).method_41821();
}
